"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ImageSizeControl;
var _components = require("@wordpress/components");
var _i18n = require("@wordpress/i18n");
var _useDimensionHandler = _interopRequireDefault(require("./use-dimension-handler"));
var _jsxRuntime = require("react/jsx-runtime");
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */

const IMAGE_SIZE_PRESETS = [25, 50, 75, 100];
const noop = () => {};

/**
 * Get scaled width and height for the given scale.
 *
 * @param {number} scale       The scale to get the scaled width and height for.
 * @param {number} imageWidth  The image width.
 * @param {number} imageHeight The image height.
 *
 * @return {Object} The scaled width and height.
 */
function getScaledWidthAndHeight(scale, imageWidth, imageHeight) {
  const scaledWidth = Math.round(imageWidth * (scale / 100));
  const scaledHeight = Math.round(imageHeight * (scale / 100));
  return {
    scaledWidth,
    scaledHeight
  };
}
function ImageSizeControl({
  imageSizeHelp,
  imageWidth,
  imageHeight,
  imageSizeOptions = [],
  isResizable = true,
  slug,
  width,
  height,
  onChange,
  onChangeImage = noop
}) {
  const {
    currentHeight,
    currentWidth,
    updateDimension,
    updateDimensions
  } = (0, _useDimensionHandler.default)(height, width, imageHeight, imageWidth, onChange);

  /**
   * Updates the dimensions for the given scale.
   * Handler for toggle group control change.
   *
   * @param {number} scale The scale to update the dimensions for.
   */
  const handleUpdateDimensions = scale => {
    if (undefined === scale) {
      updateDimensions();
      return;
    }
    const {
      scaledWidth,
      scaledHeight
    } = getScaledWidthAndHeight(scale, imageWidth, imageHeight);
    updateDimensions(scaledHeight, scaledWidth);
  };

  /**
   * Add the stored image preset value to toggle group control.
   */
  const selectedValue = IMAGE_SIZE_PRESETS.find(scale => {
    const {
      scaledWidth,
      scaledHeight
    } = getScaledWidthAndHeight(scale, imageWidth, imageHeight);
    return currentWidth === scaledWidth && currentHeight === scaledHeight;
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_components.__experimentalVStack, {
    className: "block-editor-image-size-control",
    spacing: "4",
    children: [imageSizeOptions && imageSizeOptions.length > 0 && /*#__PURE__*/(0, _jsxRuntime.jsx)(_components.SelectControl, {
      __nextHasNoMarginBottom: true,
      label: (0, _i18n.__)('Resolution'),
      value: slug,
      options: imageSizeOptions,
      onChange: onChangeImage,
      help: imageSizeHelp,
      size: "__unstable-large"
    }), isResizable && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_components.__experimentalHStack, {
        align: "baseline",
        spacing: "4",
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_components.__experimentalNumberControl, {
          label: (0, _i18n.__)('Width'),
          value: currentWidth,
          min: 1,
          onChange: value => updateDimension('width', value),
          size: "__unstable-large"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_components.__experimentalNumberControl, {
          label: (0, _i18n.__)('Height'),
          value: currentHeight,
          min: 1,
          onChange: value => updateDimension('height', value),
          size: "__unstable-large"
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_components.__experimentalToggleGroupControl, {
        label: (0, _i18n.__)('Image size presets'),
        hideLabelFromVision: true,
        onChange: handleUpdateDimensions,
        value: selectedValue,
        isBlock: true,
        __next40pxDefaultSize: true,
        __nextHasNoMarginBottom: true,
        children: IMAGE_SIZE_PRESETS.map(scale => {
          return /*#__PURE__*/(0, _jsxRuntime.jsx)(_components.__experimentalToggleGroupControlOption, {
            value: scale,
            label: (0, _i18n.sprintf)(/* translators: Percentage value. */
            (0, _i18n.__)('%d%%'), scale)
          }, scale);
        })
      })]
    })]
  });
}
//# sourceMappingURL=index.js.map