"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEventListeners = useEventListeners;
var _element = require("@wordpress/element");
var _compose = require("@wordpress/compose");
var _beforeInputRules = _interopRequireDefault(require("./before-input-rules"));
var _inputRules = _interopRequireDefault(require("./input-rules"));
var _insertReplacementText = _interopRequireDefault(require("./insert-replacement-text"));
var _removeBrowserShortcuts = _interopRequireDefault(require("./remove-browser-shortcuts"));
var _shortcuts = _interopRequireDefault(require("./shortcuts"));
var _inputEvents = _interopRequireDefault(require("./input-events"));
var _undoAutomaticChange = _interopRequireDefault(require("./undo-automatic-change"));
var _pasteHandler = _interopRequireDefault(require("./paste-handler"));
var _delete2 = _interopRequireDefault(require("./delete"));
var _enter = _interopRequireDefault(require("./enter"));
var _firefoxCompat = _interopRequireDefault(require("./firefox-compat"));
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */

const allEventListeners = [_beforeInputRules.default, _inputRules.default, _insertReplacementText.default, _removeBrowserShortcuts.default, _shortcuts.default, _inputEvents.default, _undoAutomaticChange.default, _pasteHandler.default, _delete2.default, _enter.default, _firefoxCompat.default];
function useEventListeners(props) {
  const propsRef = (0, _element.useRef)(props);
  (0, _element.useInsertionEffect)(() => {
    propsRef.current = props;
  });
  const refEffects = (0, _element.useMemo)(() => allEventListeners.map(refEffect => refEffect(propsRef)), [propsRef]);
  return (0, _compose.useRefEffect)(element => {
    if (!props.isSelected) {
      return;
    }
    const cleanups = refEffects.map(effect => effect(element));
    return () => {
      cleanups.forEach(cleanup => cleanup());
    };
  }, [refEffects, props.isSelected]);
}
//# sourceMappingURL=index.js.map